@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 
 my %construct = (
@@ -37,6 +37,7 @@ my %construct = (
                  'delete-local'    => 5.012,
                  'length-undef'    => 5.012,
                  '\N'              => 5.012,
+                 'while-readdir'   => 5.012,
 
                  '//'              => 5.010,
                  '?PARNO'          => 5.010,
@@ -84,7 +85,7 @@ Syntax::Construct - Identify which non-feature constructs are used in the code.
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =head1 SYNOPSIS
 
@@ -212,6 +213,11 @@ changes>.
 
 L<perl5120delta/\N experimental regex escape>.
 
+=head3 while-readdir
+
+C<readdir> in a while-loop condition populates C<$_>. Not mentioned in
+any delta, but see L<perlfunc/readdir>.
+
 =head2 5.014
 
 =head3 ?^
